# @anywidet/deno

[anywidget](https://anywidget.dev) for Deno Jupyter kernel.

This is a stub for npm. The actual package is published on the
[JavaScript Registry](https://jsr.io).

Please see [`jsr:@anywidget/deno`](https://jsr.io/@anywidget/deno).
